@@ -1,5 +1,9 @@
 """Provides a widget for displaying the source related to the AST view."""
 
+##############################################################################
+# Backward compatibility.
+from __future__ import annotations
+
 ##############################################################################
 # Python imports.
 from pathlib   import Path
@@ -91,7 +95,7 @@ class Source( SourceInfo, can_focus=True ):
 
         Args:
             dark_theme (str, optional): The theme to use for dark mode.
-            light_theme (str, optional)): The theme to use for light mode.
+            light_theme (str, optional): The theme to use for light mode.
         """
         super().__init__( *args, **kwargs )
         self._source_file = source
